@@ -19,6 +19,9 @@ use std::collections::{HashMap, HashSet};
 pub const API_URL: &str = "https://app.vendo.noncd.db.de/mob";
 const TZ: chrono_tz::Tz = chrono_tz::Europe::Berlin;
 
+const LOCATION_MIME: &str = "application/x.db.vendo.mob.location.v3+json";
+const VERBINDUNGSSUCHE_MIME: &str = "application/x.db.vendo.mob.verbindungssuche.v9+json";
+
 #[derive(Clone)]
 pub struct DbMovasClient<R: Requester> {
     requester: R,
@@ -166,10 +169,7 @@ impl<R: Requester> Provider<R> for DbMovasClient<R> {
             .post(
                 &url,
                 &serde_json::to_vec(&query).expect("Failed to serialize body"),
-                headers_for_content_type(
-                    "application/x.db.vendo.mob.verbindungssuche.v8+json",
-                    &correlation_id(),
-                ),
+                headers_for_content_type(VERBINDUNGSSUCHE_MIME, &correlation_id()),
             )
             .await
             .map_err(rcore::Error::Request)?;
@@ -204,10 +204,7 @@ impl<R: Requester> Provider<R> for DbMovasClient<R> {
             .post(
                 &url,
                 &serde_json::to_vec(&query).expect("Failed to serialize body"),
-                headers_for_content_type(
-                    "application/x.db.vendo.mob.location.v3+json",
-                    &correlation_id(),
-                ),
+                headers_for_content_type(LOCATION_MIME, &correlation_id()),
             )
             .await
             .map_err(rcore::Error::Request)?;
@@ -228,9 +225,6 @@ impl<R: Requester> Provider<R> for DbMovasClient<R> {
         Err(rcore::Error::NotImplemented)
     }
 
-    // This method is not guaranteed to find the same journey.
-    // TODO: Figure out how to refresh the journey based on the context
-    // TODO: Currently broken I think.
     async fn refresh_journey(
         &self,
         journey: &Journey,
@@ -252,10 +246,7 @@ impl<R: Requester> Provider<R> for DbMovasClient<R> {
             .post(
                 &url,
                 &serde_json::to_vec(&query).expect("Failed to serialize body"),
-                headers_for_content_type(
-                    "application/x.db.vendo.mob.verbindungssuche.v8+json",
-                    &correlation_id(),
-                ),
+                headers_for_content_type(VERBINDUNGSSUCHE_MIME, &correlation_id()),
             )
             .await
             .map_err(rcore::Error::Request)?;
